@@ -1,5 +1,8 @@
 package HTML::FormFu::Constraint::AutoSet;
-$HTML::FormFu::Constraint::AutoSet::VERSION = '2.01';
+
+use strict;
+our $VERSION = '2.03'; # VERSION
+
 use Moose;
 extends 'HTML::FormFu::Constraint::Set';
 
@@ -20,6 +23,9 @@ sub _parse_value {
         return map { _parse_value($_) } @{ $item->{group} };
     }
     else {
+        # disabled attributes should be ignored
+        return if ($item->{attributes} and $item->{attributes}->{disabled});
+        # anything else is fine
         return $item->{value};
     }
 }
@@ -34,6 +40,10 @@ __END__
 
 HTML::FormFu::Constraint::AutoSet - Set Constraint for Selects / Radiogroups / Checkboxgroups
 
+=head1 VERSION
+
+version 2.03
+
 =head1 DESCRIPTION
 
 For use with L<HTML::FormFu::Element::Radiogroup>,
