@@ -1,5 +1,8 @@
 package HTML::FormFu::Constraint::File::MIME;
-$HTML::FormFu::Constraint::File::MIME::VERSION = '2.01';
+
+use strict;
+our $VERSION = '2.03'; # VERSION
+
 use Moose;
 use MooseX::Attribute::FormFuChained;
 extends 'HTML::FormFu::Constraint';
@@ -46,6 +49,10 @@ __END__
 
 HTML::FormFu::Constraint::File::MIME - MIME Type Constraint
 
+=head1 VERSION
+
+version 2.03
+
 =head1 DESCRIPTION
 
 Constraint an uploaded file's MIME-type (Content-Type).
@@ -62,8 +69,8 @@ Arguments: \@mime_types
 
 Optional.
 
-Accepts a single MIME-type or an arrayref of MIME-types. Each is checked 
-against the uploaded file's MIME-type (as given by the browser), and the 
+Accepts a single MIME-type or an arrayref of MIME-types. Each is checked
+against the uploaded file's MIME-type (as given by the browser), and the
 constraint passes if any one of the given types matches.
 
 =head2 regex
@@ -72,10 +79,10 @@ Arguments: $regex
 
 Optional.
 
-Accepts a string to be interpreted as a regex, and is checked against the 
+Accepts a string to be interpreted as a regex, and is checked against the
 uploaded files's MIME-type (as given by the browser).
 
-The regex uses the C</x> flag, so that whitespace in the given string is 
+The regex uses the C</x> flag, so that whitespace in the given string is
 ignored.
 
 =head1 SEE ALSO
