@@ -1,5 +1,8 @@
 package HTML::FormFu::Constraint::Integer;
-$HTML::FormFu::Constraint::Integer::VERSION = '2.01';
+
+use strict;
+our $VERSION = '2.03'; # VERSION
+
 use Moose;
 extends 'HTML::FormFu::Constraint::Regex';
 
@@ -15,6 +18,10 @@ __END__
 
 HTML::FormFu::Constraint::Integer - Unsigned Integer Constraint
 
+=head1 VERSION
+
+version 2.03
+
 =head1 DESCRIPTION
 
 Integer constraint.
@@ -30,7 +37,7 @@ L<HTML::FormFu>
 
 Carl Franks, C<cfranks@cpan.org>
 
-Based on the original source code of L<HTML::Widget::Constraint::Integer>, by 
+Based on the original source code of L<HTML::Widget::Constraint::Integer>, by
 Sebastian Riedel, C<sri@oook.de>.
 
 =head1 LICENSE
