@@ -1,5 +1,8 @@
 package HTML::FormFu::Constraint::MaxLength;
-$HTML::FormFu::Constraint::MaxLength::VERSION = '2.01';
+
+use strict;
+our $VERSION = '2.03'; # VERSION
+
 use Moose;
 extends 'HTML::FormFu::Constraint::Length';
 
@@ -19,11 +22,15 @@ __END__
 
 HTML::FormFu::Constraint::MaxLength - Maximum Length String Constraint
 
+=head1 VERSION
+
+version 2.03
+
 =head1 DESCRIPTION
 
 Checks the input value meets a maximum length.
 
-Overrides L<HTML::FormFu::Constraint/localize_args>, so that the value of 
+Overrides L<HTML::FormFu::Constraint/localize_args>, so that the value of
 L</maximum> is passed as an argument to L<localize|HTML::FormFu/localize>.
 
 This constraint doesn't honour the C<not()> value.
