@@ -1,5 +1,8 @@
 package HTML::FormFu::Deflator::Callback;
-$HTML::FormFu::Deflator::Callback::VERSION = '2.01';
+
+use strict;
+our $VERSION = '2.03'; # VERSION
+
 use Moose;
 use MooseX::Attribute::FormFuChained;
 extends 'HTML::FormFu::Deflator';
@@ -11,6 +14,7 @@ sub deflator {
 
     my $callback = $self->callback || sub {shift};
 
+    ## no critic (ProhibitNoStrict);
     no strict 'refs';
 
     return $callback->($value);
@@ -26,6 +30,10 @@ __END__
 
 HTML::FormFu::Deflator::Callback - Callback deflator
 
+=head1 VERSION
+
+version 2.03
+
 =head1 SYNOPSIS
 
     $field->deflator('Callback')->callback( \&my_callback );
