@@ -1,15 +1,15 @@
 package HTML::FormFu::Deflator::PathClassFile;
-{
-  $HTML::FormFu::Deflator::PathClassFile::VERSION = '1.00';
-}
+
+use strict;
+our $VERSION = '2.03'; # VERSION
 
 use Moose;
-use MooseX::Attribute::Chained;
+use MooseX::Attribute::FormFuChained;
 extends 'HTML::FormFu::Deflator';
 
-has relative => ( is => 'rw', traits => ['Chained'] );
-has absolute => ( is => 'rw', traits => ['Chained'] );
-has basename => ( is => 'rw', traits => ['Chained'] );
+has relative => ( is => 'rw', traits => ['FormFuChained'] );
+has absolute => ( is => 'rw', traits => ['FormFuChained'] );
+has basename => ( is => 'rw', traits => ['FormFuChained'] );
 
 sub deflator {
     my ( $self, $value ) = @_;
@@ -45,6 +45,10 @@ __END__
 
 HTML::FormFu::Deflator::PathClassFile - Deflator for Path::Class::File objects
 
+=head1 VERSION
+
+version 2.03
+
 =head1 SYNOPSIS
 
     $form->deflator( PathClassFile => 'file' )
@@ -67,14 +71,14 @@ There are three types of deflation:
 
 =item relative
 
-Set this to 1 to deflate to a relative path. Anything else than 1 specifies the 
-directory to use as the base of relativity - otherwise the current working 
+Set this to 1 to deflate to a relative path. Anything else than 1 specifies the
+directory to use as the base of relativity - otherwise the current working
 directory will be used.
 
 =item absolute
 
-Set this to 1 to deflate to an absolute path. Anything else than 1 specifies the 
-directory to use as the base of relativity - otherwise the current working 
+Set this to 1 to deflate to an absolute path. Anything else than 1 specifies the
+directory to use as the base of relativity - otherwise the current working
 directory will be used.
 
 =item basename
