@@ -1,5 +1,8 @@
 package HTML::FormFu::Element::File;
-$HTML::FormFu::Element::File::VERSION = '2.01';
+
+use strict;
+our $VERSION = '2.03'; # VERSION
+
 use Moose;
 
 extends 'HTML::FormFu::Element';
@@ -26,6 +29,10 @@ __END__
 
 HTML::FormFu::Element::File - File upload form field
 
+=head1 VERSION
+
+version 2.03
+
 =head1 SYNOPSIS
 
     ---
@@ -34,14 +41,14 @@ HTML::FormFu::Element::File - File upload form field
       name: photo
 
     my $photo = $form->param('photo');
-    
+
     my $blob = $photo->slurp;
 
 =head1 DESCRIPTION
 
 File upload form field.
 
-See the documentation relevant to the L<query_type|HTML::FormFu/query_type> 
+See the documentation relevant to the L<query_type|HTML::FormFu/query_type>
 you're using:
 
 =over
@@ -58,9 +65,9 @@ you're using:
 
 =head1 SEE ALSO
 
-Is a sub-class of, and inherits methods from 
-L<HTML::FormFu::Role::Element::Input>, 
-L<HTML::FormFu::Role::Element::Field>, 
+Is a sub-class of, and inherits methods from
+L<HTML::FormFu::Role::Element::Input>,
+L<HTML::FormFu::Role::Element::Field>,
 L<HTML::FormFu::Element>
 
 L<HTML::FormFu>
