@@ -1,5 +1,8 @@
 package HTML::FormFu::Exception::Inflator;
-$HTML::FormFu::Exception::Inflator::VERSION = '2.01';
+
+use strict;
+our $VERSION = '2.03'; # VERSION
+
 use Moose;
 extends 'HTML::FormFu::Exception::Input';
 
