@@ -1,7 +1,7 @@
 package HTML::FormFu::Exception::Transformer;
-{
-  $HTML::FormFu::Exception::Transformer::VERSION = '1.00';
-}
+
+use strict;
+our $VERSION = '2.03'; # VERSION
 
 use Moose;
 extends 'HTML::FormFu::Exception::Input';
