@@ -1,5 +1,8 @@
 package HTML::FormFu::Filter::LowerCase;
-$HTML::FormFu::Filter::LowerCase::VERSION = '2.01';
+
+use strict;
+our $VERSION = '2.03'; # VERSION
+
 use Moose;
 extends 'HTML::FormFu::Filter';
 
@@ -21,6 +24,10 @@ __END__
 
 HTML::FormFu::Filter::LowerCase - filter transforming to lower case
 
+=head1 VERSION
+
+version 2.03
+
 =head1 DESCRIPTION
 
 LowerCase transforming filter.
@@ -29,7 +36,7 @@ LowerCase transforming filter.
 
 Carl Franks, C<cfranks@cpan.org>
 
-Based on the original source code of L<HTML::Widget::Filter::LowerCase>, by 
+Based on the original source code of L<HTML::Widget::Filter::LowerCase>, by
 Lyo Kato, C<lyo.kato@gmail.com>
 
 =head1 LICENSE
