@@ -1,5 +1,8 @@
 package HTML::FormFu::Filter::Regex;
-$HTML::FormFu::Filter::Regex::VERSION = '2.01';
+
+use strict;
+our $VERSION = '2.03'; # VERSION
+
 use Moose;
 use MooseX::Attribute::FormFuChained;
 extends 'HTML::FormFu::Filter';
@@ -38,6 +41,10 @@ __END__
 
 HTML::FormFu::Filter::Regex - regexp-based match/replace filter
 
+=head1 VERSION
+
+version 2.03
+
 =head1 SYNOPSIS
 
 The following filter would turn C<1234-5678> into C<****-****>.
@@ -54,14 +61,14 @@ Regular expression-based match / replace filter.
 
 =head2 match
 
-A regex object or string to be used in the "left-hand side" of a C<s///g> 
+A regex object or string to be used in the "left-hand side" of a C<s///g>
 regular expression.
 
 Default Value: qr/./
 
 =head2 replace
 
-A string to be used in the "right-hand side" of a C<s///g> regular 
+A string to be used in the "right-hand side" of a C<s///g> regular
 expression. The string will replace every occurrence of L</match>.
 
 Default Value: ''
