@@ -1,5 +1,8 @@
 package HTML::FormFu::Filter::Split;
-$HTML::FormFu::Filter::Split::VERSION = '2.01';
+
+use strict;
+our $VERSION = '2.03'; # VERSION
+
 use Moose;
 use MooseX::Attribute::FormFuChained;
 extends 'HTML::FormFu::Filter';
@@ -34,6 +37,10 @@ __END__
 
 HTML::FormFu::Filter::Split - filter splitting a singe value into an arrayref
 
+=head1 VERSION
+
+version 2.03
+
 =head1 SYNOPSIS
 
     type: Split
