@@ -1,5 +1,8 @@
 package HTML::FormFu::Filter::TrimEdges;
-$HTML::FormFu::Filter::TrimEdges::VERSION = '2.01';
+
+use strict;
+our $VERSION = '2.03'; # VERSION
+
 use Moose;
 extends 'HTML::FormFu::Filter';
 
@@ -24,6 +27,10 @@ __END__
 
 HTML::FormFu::Filter::TrimEdges - filter trimming whitespace
 
+=head1 VERSION
+
+version 2.03
+
 =head1 DESCRIPTION
 
 Trim whitespaces from beginning and end of string.
