@@ -1,5 +1,8 @@
 package HTML::FormFu::I18N;
-$HTML::FormFu::I18N::VERSION = '2.01';
+
+use strict;
+our $VERSION = '2.03'; # VERSION
+
 use Moose;
 
 extends 'Locale::Maketext';
