@@ -1,7 +1,10 @@
 package HTML::FormFu::I18N::fr;
-$HTML::FormFu::I18N::fr::VERSION = '2.01';
+
 use utf8;
 
+use strict;
+our $VERSION = '2.03'; # VERSION
+
 use Moose;
 extends 'HTML::FormFu::I18N';
 
