@@ -1,10 +1,10 @@
 package HTML::FormFu::OutputProcessor::StripWhitespace;
-{
-  $HTML::FormFu::OutputProcessor::StripWhitespace::VERSION = '1.00';
-}
+
+use strict;
+our $VERSION = '2.03'; # VERSION
 
 use Moose;
-use MooseX::Attribute::Chained;
+use MooseX::Attribute::FormFuChained;
 extends 'HTML::FormFu::OutputProcessor';
 
 use HTML::FormFu::Constants qw( $EMPTY_STR );
@@ -28,7 +28,7 @@ has collapse_tags => (
                 ) ];
     },
     lazy   => 1,
-    traits => ['Chained'],
+    traits => ['FormFuChained'],
 );
 
 has collapse_consecutive_tags => (
@@ -40,7 +40,7 @@ has collapse_consecutive_tags => (
                 ) ];
     },
     lazy   => 1,
-    traits => ['Chained'],
+    traits => ['FormFuChained'],
 );
 
 sub process {
@@ -123,11 +123,12 @@ sub process {
 __PACKAGE__->meta->make_immutable;
 
 package HTML::FormFu::OutputProcessor::StripWhitespace::_iter;
-{
-  $HTML::FormFu::OutputProcessor::StripWhitespace::_iter::VERSION = '1.00';
-}
+
+use strict;
+our $VERSION = '2.03'; # VERSION
+
 use Moose;
-use MooseX::Attribute::Chained;
+use MooseX::Attribute::FormFuChained;
 
 sub new {
     my ( $class, @tags ) = @_;
@@ -173,6 +174,10 @@ __END__
 
 HTML::FormFu::OutputProcessor::StripWhitespace - Strip shitespace from HTML output
 
+=head1 VERSION
+
+version 2.03
+
 =head1 SYNOPSIS
 
     ---
