@@ -1,5 +1,8 @@
 package HTML::FormFu::Role::Element::Coercible;
-$HTML::FormFu::Role::Element::Coercible::VERSION = '2.01';
+
+use strict;
+our $VERSION = '2.03'; # VERSION
+
 use Moose::Role;
 
 use Carp qw( croak );
@@ -24,7 +27,7 @@ sub _coerce {
     }
 
     my $class = $args{type};
-    if ( $class !~ /^\+/ ) {
+    if ( $class !~ m/^\+/ ) {
         $class = "HTML::FormFu::Element::$class";
     }
 
