@@ -1,5 +1,8 @@
 package HTML::FormFu::Role::Element::FieldMethods;
-$HTML::FormFu::Role::Element::FieldMethods::VERSION = '2.01';
+
+use strict;
+our $VERSION = '2.03'; # VERSION
+
 use Moose::Role;
 
 use Carp qw( croak );
