@@ -1,5 +1,8 @@
 package HTML::FormFu::Role::FormAndBlockMethods;
-$HTML::FormFu::Role::FormAndBlockMethods::VERSION = '2.01';
+
+use strict;
+our $VERSION = '2.03'; # VERSION
+
 use Moose::Role;
 
 use HTML::FormFu::Util qw( _merge_hashes );
