@@ -1,11 +1,13 @@
 package HTML::FormFu::Transformer;
-$HTML::FormFu::Transformer::VERSION = '2.01';
+
+use strict;
+our $VERSION = '2.03'; # VERSION
+
 use Moose;
 extends 'HTML::FormFu::Processor';
 
 use HTML::FormFu::Exception::Transformer;
 use Scalar::Util qw( blessed );
-use Carp qw( croak );
 
 sub process {
     my ( $self, $values, $params ) = @_;
@@ -61,6 +63,10 @@ __END__
 
 HTML::FormFu::Transformer - Transformer Base Class
 
+=head1 VERSION
+
+version 2.03
+
 =head1 SYNOPSIS
 
 =head1 DESCRIPTION
