@@ -1,5 +1,8 @@
 package HTML::FormFu::Validator::Callback;
-$HTML::FormFu::Validator::Callback::VERSION = '2.01';
+
+use strict;
+our $VERSION = '2.03'; # VERSION
+
 use Moose;
 use MooseX::Attribute::FormFuChained;
 extends 'HTML::FormFu::Validator';
@@ -11,6 +14,7 @@ sub validate_value {
 
     my $callback = $self->callback || sub {1};
 
+    ## no critic (ProhibitNoStrict);
     no strict 'refs';
 
     my $ok = $callback->($value);
@@ -28,6 +32,10 @@ __END__
 
 HTML::FormFu::Validator::Callback - Callback validator
 
+=head1 VERSION
+
+version 2.03
+
 =head1 SYNOPSIS
 
     $field->validator('Callback')->callback( \&my_validator );
